# vim: set ts=4 sw=4 et:

# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/

%define soname 0

%if 0%{?suse_version} > 1120
%bcond_with gtk1
%else
%bcond_without gtk1
%endif

Name:           lame
Version:        3.99.5
Release:        1002.1
License:        LGPL-2.0+
URL:            http://lame.sourceforge.net/
Summary:        LAME Ain't an MP3 Encoder
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Source:         http://prdownloads.sourceforge.net/lame/lame-%{version}.tar.gz
Source99:       lame-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%ifarch %{ix86}
BuildRequires:  nasm
%endif
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
%if %{with gtk1}
BuildRequires:  gtk-devel
%endif
Requires:       libmp3lame%{soname} >= %{version}

%description
LAME is an educational tool to be used for learning about MP3 encoding.
The goal of the LAME project is to use the open source model to improve the
psycho acoustics, noise shaping and speed of MP3.
Another goal of the LAME project is to use these improvements for the basis of
a patent free audio compression codec for the GNU project.

%package doc
Summary:        LAME Ain't an MP3 Encoder (Documentation)
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Requires:       %{name} = %{version}

%description doc
LAME is an educational tool to be used for learning about MP3 encoding.
The goal of the LAME project is to use the open source model to improve the
psycho acoustics, noise shaping and speed of MP3.
Another goal of the LAME project is to use these improvements for the basis of
a patent free audio compression codec for the GNU project.

This package contains additional documentation files in
  %{_defaultdocdir}/%{name}/

%package -n libmp3lame%{soname}
Summary:        LAME Ain't an MP3 Encoder
Group:          System/Libraries

%description -n libmp3lame%{soname}
LAME is an educational tool to be used for learning about MP3 encoding.
The goal of the LAME project is to use the open source model to improve the
psycho acoustics, noise shaping and speed of MP3.
Another goal of the LAME project is to use these improvements for the basis of
a patent free audio compression codec for the GNU project.

%package -n libmp3lame-devel
Summary:        LAME Ain't an MP3 Encoder
Group:          Development/Libraries/C and C++
Requires:       libmp3lame%{soname} = %{version}

%description -n libmp3lame-devel
LAME is an educational tool to be used for learning about MP3 encoding.
The goal of the LAME project is to use the open source model to improve the
psycho acoustics, noise shaping and speed of MP3.
Another goal of the LAME project is to use these improvements for the basis of
a patent free audio compression codec for the GNU project.

%package -n lame-mp3rtp
Summary:        MP3 Encoder for RTP Streaming
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Requires:       libmp3lame%{soname} >= %{version}

%description -n lame-mp3rtp
LAME is an educational tool to be used for learning about MP3 encoding.
The goal of the LAME project is to use the open source model to improve the
psycho acoustics, noise shaping and speed of MP3.
Another goal of the LAME project is to use these improvements for the basis of
a patent free audio compression codec for the GNU project.

This package includes "mp3rtp", an MP3 encoder with RTP streaming of the output.

%if %{with gtk1}
%package -n lame-mp3x
Summary:        MP3 Frame Analyzer
Group:          Productivity/Multimedia/Sound/Visualization
Requires:       libmp3lame%{soname} >= %{version}

%description -n lame-mp3x
LAME is an educational tool to be used for learning about MP3 encoding.
The goal of the LAME project is to use the open source model to improve the
psycho acoustics, noise shaping and speed of MP3.
Another goal of the LAME project is to use these improvements for the basis of
a patent free audio compression codec for the GNU project.

This package includes "mp3x", an MP3 frame analyzer with a graphical
frontend.
%endif

%prep
%setup -q
%if 0%{?suse_version} > 1210
find . -type f \( -name configure.in -o -name Makefile.am \) | while read f; do
    perl -n -i.orig -e 's/\s+\S*ansi2knr// if /^AUTOMAKE_OPTIONS/ ; print unless /^AM_C_PROTOTYPES/' "$f"
done
%endif

%if !%{with gtk1}
# dirty
sed -i -e 's/AM_PATH_GTK.*/HAVE_GTK=no/' configure.in
sed -i -e s/@GTK_CFLAGS@// frontend/Makefile.am
%endif

%build
LIBS="-lm" \
CFLAGS="%{optflags}" \
%configure \
    --enable-nasm \
    --enable-decoder \
    --without-vorbis \
    --enable-analyzer=no \
    --enable-brhist \
    --disable-debug \
    --enable-mp3rtp \
%if %{with gtk1}
    --enable-mp3x \
%endif
    --with-fileio=lame \
    --enable-dynamic-frontends \
    --disable-rpath \
    --disable-static
 
%__make %{?_smp_flags} pkgdocdir=%{_defaultdocdir}/%{name}/

%install
%__make install pkgdocdir=%{_defaultdocdir}/%{name}/ DESTDIR="%{buildroot}"
rm -f %{buildroot}%{_libdir}/libmp3lame.la

for f in ChangeLog README TODO USAGE; do
    install -m0644 "$f" "%{buildroot}%{_defaultdocdir}/%{name}/"
done

%post   -n libmp3lame%{soname} -p /sbin/ldconfig
%postun -n libmp3lame%{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/lame
%{_mandir}/man1/lame.1*

%files doc
%defattr(-,root,root)
%{_defaultdocdir}/%{name}

%files -n libmp3lame%{soname}
%defattr(0644,root,root,0755)
%doc COPYING LICENSE
%{_libdir}/libmp3lame.so.%{soname}
%{_libdir}/libmp3lame.so.%{soname}.*

%files -n libmp3lame-devel
%defattr(-,root,root)
%doc API HACKING STYLEGUIDE
%{_includedir}/lame/
%{_libdir}/libmp3lame.so

%files -n lame-mp3rtp
%defattr(-,root,root)
%{_bindir}/mp3rtp

%if %{with gtk1}
%files -n lame-mp3x
%defattr(-,root,root)
%{_bindir}/mp3x
%endif

%changelog
* Sun Dec 18 2011 cs@linux-administrator.com
- re-import
